@@ -14,6 +14,7 @@
 import os
 import sys
 import logging
+import signal
 import argparse
 import botocore.exceptions
 
@@ -22,6 +23,8 @@ from .resolver import InstanceResolver
 
 logger = logging.getLogger()
 
+signal.signal(signal.SIGTSTP, signal.SIG_IGN)   # Ignore Ctrl-Z - pass it on to the shell
+
 def parse_args(argv):
     """
     Parse command line arguments.
@@ -86,7 +89,7 @@ def start_session(instance_id, args):
         if args.document_name:
             ssm_args += f"--document-name {args.document_name} "
         if args.parameters:
-            ssm_args += f"--parameters {args.parameters} "
+            ssm_args += f"--parameters '{args.parameters}' "
 
     command = f'aws {aws_args} ssm start-session --target {instance_id} {ssm_args}'
     logger.info("Running: %s", command)
